#!/bin/bash
set -e

###############################################################################
# Script para lançamento de versão com criação de tag no repositório e
# preparação para a nova versão snapshot.
# Uso: ./release-prepare-npm.sh VERSION_TO_RELEASE NEXT_SNAPSHOT_VERSION
###############################################################################

if [ "$#" != 2 ]
then
    echo "Uso: $0 <VERSION_TO_RELEASE> <NEXT_SNAPSHOT_VERSION>"
    exit
fi

RELEASE=$1
SNAPSHOT=$2

checkIsMaster()
{
   res=$(git rev-parse --abbrev-ref HEAD)
   if [[ "$res" != "master" ]]; then
      echo "[Error] Tag can only be generated from master!"
      exit -1  
   fi
}

changeVersion()
{
   fileName=$1
   version=$2
   sed -i -E "s/^version[[:space:]]*=[[:space:]]*.*$/version = \"$version\"/" $fileName
}

changeRockSpecs()
{
   version=$1
   echo "Setting version $version..."
   changeVersion "sga-daemon-*.rockspec" $version
   changeVersion "sga-driver-posix-*.rockspec" $version 
   changeVersion "sga-driver-pbs-*.rockspec" $version 
   changeVersion "sga-driver-slurm-*.rockspec" $version 
   changeVersion "sga-exec-*.rockspec" $version 
}

renameRockSpecs()
{
   version=$1
   echo "Rename files to version $version..."
   mv sga-daemon-*.rockspec sga-daemon-$version.rockspec
   mv sga-driver-posix-*.rockspec sga-driver-posix-$version.rockspec
   mv sga-driver-pbs-*.rockspec sga-driver-pbs-$version.rockspec
   mv sga-driver-slurm-*.rockspec sga-driver-slurm-$version.rockspec
   mv sga-exec-*.rockspec sga-exec-$version.rockspec
}

stageRockSpecs()
{
	# Acrescenta os removidos
   git status | grep "deleted" | awk '{print "git add "$2}' | sh -
   # Acrescenta os novos
   git add *.rockspec
}


releaseVersion()
{
   echo "[..] release version $RELEASE..."
   changeRockSpecs $RELEASE
   renameRockSpecs $RELEASE
   stageRockSpecs
   git commit -m "[sgarest-daemon release] prepare release $RELEASE" && \
   git tag -a $RELEASE -m "Release version $RELEASE." && \
   git push --follow-tags && \
	echo "[ok]"
}

nextSnapshotVersion()
{
   echo "[..] prepare for next development $SNAPSHOT..."
   changeRockSpecs $SNAPSHOT
   renameRockSpecs $SNAPSHOT
   stageRockSpecs
   git commit -m "[sgarest-daemon release] prepare for next development $SNAPSHOT" && \
   git push && \
   echo "[ok]"
}

checkIsMaster
releaseVersion 
nextSnapshotVersion 

echo "Success".

exit 0;
