
local filemonitor = {}

local util = require("sga.util")
local stat = require("posix.sys.stat")
local base64 = require('base64')

local function read_chunck(job, file)
  local offset = (job.data[file] and job.data[file].chunk_offset) or 0
  local seq = (job.data[file] and job.data[file].chunk_seq) or 0

  local chunk = util.read_file(file, offset)
  if not chunk or chunk:len() == 0 then
    return nil
  end

  if not job.data[file] then
    job.data[file] = {}
  end
  local data = job.data[file]
  data.chunk_offset = offset + chunk:len()
  data.chunk_seq = seq + 1
  return chunk, data.chunk_seq
end

function filemonitor.read_files(job)
  local params = job.parameters
  local path = job.parameters.csbase_command_output_path
  local ret = {}
  local i = 1
  for filename, file_data in pairs(job.data) do
    local filepath = path.."/"..filename
    if stat.stat(filepath) then
      local chunk, chunk_seq = read_chunck(job, filepath)
      if chunk then
        ret["monitor_file."..i] = filename
        ret["monitor_file_chunk."..i] = base64.encode(chunk)
        ret["monitor_file_chunk_seq."..i] = chunk_seq
        i = i + 1
      end
    end
  end
  return ret
end

function filemonitor.init(job)
  local params = job.parameters
  local i = 1
  while true do
    local filename = params["csbase_command_monitor_file."..i]
    if not filename then
      break
    else
      job.data[filename] = {}
      i = i + 1
    end    
  end
end

-- local function single(job)
--   local filename = "out.log"
--   local filepath = job.parameters.csbase_command_output_path.."/"..filename
--   if not stat.stat(filepath) then
--     return {}
--   else
--     local chunk, chunk_seq = read_file(job, filepath)
--     if chunk then
--       return { log_chunk = chunk, log_chunk_seq = chunk_seq }
--     else
--       return {}
--     end
--   end
-- end

-- local function multiple(job)
--   local ret = {}
--   local fileformat = "out%d.log"
--   for i=0,100 do
--     local filename = string.format(fileformat, i)
--     local filepath = job.parameters.csbase_command_output_path.."/"..filename
--     if not stat.stat(filepath) then
--       break
--     else
--       local chunk, chunk_seq = read_file(job, filepath)
--       if chunk then
--         ret["log_chunk."..i] = chunk
--         ret["log_chunk_seq."..i] = chunk_seq
--       end
--     end
--   end
--   return ret
-- end  

-- function filemonitor.read(job)
--   local singlelog = single(job)
--   local multiplelog = multiple(job)
--   for k,v in pairs(singlelog) do
--     multiplelog[k] = v
--   end
--   return multiplelog
-- end

return filemonitor