#!/bin/sh

timestamp=$(date +%Y%m%d%H%M%S)
logsdir="logs"

[ ! -e $logsdir ] && echo "mkdir $logsdir" && mkdir $logsdir

logfile="logs/sgad_${timestamp}.log"

usage() {
   echo "usage: $0 [configfile] [options]"
   echo "Available options are:"
   echo "  --sga_name NAME  SGA name to get config from a multiple config file"
   echo "  --debug          Enable debug information: show interpreted configuration."
}

POSITIONAL="" # String para salvar argumentos passados ao comando
debug=0
while [ $# -gt 0 ] # Percorre todos argumentos
do
   case "$1" in
      --sga_name)
         sga_name="$2"
         shift
         shift
         ;;
      --sga_name=*)
         sga_name="${1#*=}"
         shift
         ;;
      --debug)
         debug=1
         shift
         ;;
      --*)
         echo "$0: unrecognized option '$1'"
         usage
         exit 1
         ;;
      *)
         if [ -n "$POSITIONAL" ]; then
            echo "$0: invalid argument '$1'"
            usage
            exit 1
         fi
         POSITIONAL="$1"
         shift
         ;;
   esac
done
set -- "${POSITIONAL}" # Reseta a posição do $N que foi shiftada
configfile=$1 # Como shiftamos todos os argumentos para a direita, nosso $1 sempre vai ser o argumento config_file, se ele existir
if [ -z ${configfile} ]; then
   echo "Using default file configuration" > ${logfile};
   configfile=sgad.cfg
fi

eval $(luarocks path --bin)
sgad ${configfile} ${debug} ${sga_name} 2>&1 | tee -a "${logfile}"
